==> mx-select-sound_24.3.tar.xz: BUILD/translations/mx-select-sound_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="48"/>
        <location filename="../mainwindow.cpp" line="79"/>
        <location filename="../mainwindow.cpp" line="135"/>
        <location filename="../mainwindow.cpp" line="155"/>
        <location filename="../mainwindow.cpp" line="163"/>
        <source>MX Select Sound</source>
        <translation type="unfinished">MX Soundkartenwahl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your current default sound card is:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ihre aktuelle voreingestellte Soundkarte ist:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>Display help </source>
        <translation type="unfinished">Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Help</source>
        <translation type="unfinished">Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Alt+H</source>
        <translation type="unfinished">Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>About this application</source>
        <translation type="unfinished">Infos zu diesem Programm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>About...</source>
        <translation type="unfinished">Über...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>Alt+B</source>
        <translation type="unfinished">Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>Quit application</source>
        <translation type="unfinished">Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Close</source>
        <translation type="unfinished">Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <source>Apply</source>
        <translation type="unfinished">Anwenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select another sound card if necessary:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wählen Sie eine andere Soundkarte, wenn nötig:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your computer has more than one sound card, you can use this application to select the one to be default. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Falls Ihr Computer über mehr als eine Soundkarte verfügt, können Sie mit dieser Anwendung eine davon als voreingestellt (default) festlegen.&lt;/br&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Test current sound card</source>
        <translation type="unfinished">Aktuelle Soundkarte testen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="79"/>
        <source>No sound cards/devices were found.</source>
        <translation type="unfinished">Keine Soundkarte gefunden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="91"/>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>none</source>
        <translation type="unfinished">keine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="134"/>
        <source>About MX Select Sound</source>
        <translation type="unfinished">Über MX Soundkartenwahl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>Version: </source>
        <translation type="unfinished">Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <source>Program for selecting the default sound card in MX Linux</source>
        <translation type="unfinished">Programm zur Auswahl der voreingestellten (default) Soundkarte in MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="155"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="163"/>
        <source>Could not play test sound.</source>
        <translation type="unfinished">Der Testklang konnte nicht abgespielt werden.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation type="unfinished">Lizenz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished">Änderungsprotokoll</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Schließen</translation>
    </message>
</context>
<context>
    <name>mxselectsound</name>
    <message>
        <source>MX Select Sound</source>
        <translation type="vanished">MX Soundkartenwahl</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your current default sound card is:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ihre aktuelle voreingestellte Soundkarte ist:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Display help </source>
        <translation type="vanished">Hilfe anzeigen</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="vanished">Hilfe</translation>
    </message>
    <message>
        <source>Alt+H</source>
        <translation type="vanished">Alt+H</translation>
    </message>
    <message>
        <source>About this application</source>
        <translation type="vanished">Infos zu diesem Programm</translation>
    </message>
    <message>
        <source>About...</source>
        <translation type="vanished">Über...</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="vanished">Alt+B</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="vanished">Anwendung beenden</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Schließen</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="vanished">Alt+N</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="vanished">Anwenden</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select another sound card if necessary:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wählen Sie eine andere Soundkarte, wenn nötig:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your computer has more than one sound card, you can use this application to select the one to be default. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Falls Ihr Computer über mehr als eine Soundkarte verfügt, können Sie mit dieser Anwendung eine davon als voreingestellt (default) festlegen.&lt;/br&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Test current sound card</source>
        <translation type="vanished">Aktuelle Soundkarte testen</translation>
    </message>
    <message>
        <source>No sound cards/devices were found.</source>
        <translation type="vanished">Keine Soundkarte gefunden.</translation>
    </message>
    <message>
        <source>none</source>
        <translation type="vanished">keine</translation>
    </message>
    <message>
        <source>About MX Select Sound</source>
        <translation type="vanished">Über MX Soundkartenwahl</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Version:</translation>
    </message>
    <message>
        <source>Program for selecting the default sound card in MX Linux</source>
        <translation type="vanished">Programm zur Auswahl der voreingestellten (default) Soundkarte in MX Linux</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Lizenz</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Änderungsprotokoll</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Abbrechen</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Schließen</translation>
    </message>
    <message>
        <source>Could not play test sound.</source>
        <translation type="vanished">Der Testklang konnte nicht abgespielt werden.</translation>
    </message>
</context>
</TS>

==> mx-select-sound_25.4.tar.xz: BUILD/translations/mx-select-sound_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="48"/>
        <location filename="../mainwindow.cpp" line="79"/>
        <location filename="../mainwindow.cpp" line="135"/>
        <location filename="../mainwindow.cpp" line="155"/>
        <location filename="../mainwindow.cpp" line="163"/>
        <source>MX Select Sound</source>
        <translation type="unfinished">MX Soundkartenwahl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your current default sound card is:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ihre aktuelle voreingestellte Soundkarte ist:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>Display help </source>
        <translation type="unfinished">Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Help</source>
        <translation type="unfinished">Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Alt+H</source>
        <translation type="unfinished">Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>About this application</source>
        <translation type="unfinished">Über diese Anwendung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>About...</source>
        <translation type="unfinished">Über...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>Alt+B</source>
        <translation type="unfinished">Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>Quit application</source>
        <translation type="unfinished">Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Close</source>
        <translation type="unfinished">Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <source>Apply</source>
        <translation type="unfinished">Anwenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select another sound card if necessary:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wählen Sie eine andere Soundkarte, wenn nötig:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your computer has more than one sound card, you can use this application to select the one to be default. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Falls Ihr Computer über mehr als eine Soundkarte verfügt, können Sie mit dieser Anwendung eine davon als voreingestellt (default) festlegen.&lt;/br&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Test current sound card</source>
        <translation type="unfinished">Aktuelle Soundkarte testen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="79"/>
        <source>No sound cards/devices were found.</source>
        <translation type="unfinished">Keine Soundkarte gefunden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="91"/>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>none</source>
        <translation type="unfinished">keine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="134"/>
        <source>About MX Select Sound</source>
        <translation type="unfinished">Über MX Soundkartenwahl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>Version: </source>
        <translation type="unfinished">Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <source>Program for selecting the default sound card in MX Linux</source>
        <translation type="unfinished">Programm zur Auswahl der voreingestellten (default) Soundkarte in MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="155"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="163"/>
        <source>Could not play test sound.</source>
        <translation type="unfinished">Der Testklang konnte nicht abgespielt werden.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation type="unfinished">Lizenz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished">Änderungsprotokoll</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Schließen</translation>
    </message>
</context>
<context>
    <name>mxselectsound</name>
    <message>
        <source>MX Select Sound</source>
        <translation type="vanished">MX Soundkartenwahl</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your current default sound card is:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ihre aktuelle voreingestellte Soundkarte ist:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Display help </source>
        <translation type="vanished">Hilfe anzeigen</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="vanished">Hilfe</translation>
    </message>
    <message>
        <source>Alt+H</source>
        <translation type="vanished">Alt+H</translation>
    </message>
    <message>
        <source>About this application</source>
        <translation type="vanished">Über diese Anwendung</translation>
    </message>
    <message>
        <source>About...</source>
        <translation type="vanished">Über...</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="vanished">Alt+B</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="vanished">Anwendung beenden</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Schließen</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="vanished">Alt+N</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="vanished">Anwenden</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select another sound card if necessary:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wählen Sie eine andere Soundkarte, wenn nötig:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your computer has more than one sound card, you can use this application to select the one to be default. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Falls Ihr Computer über mehr als eine Soundkarte verfügt, können Sie mit dieser Anwendung eine davon als voreingestellt (default) festlegen.&lt;/br&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Test current sound card</source>
        <translation type="vanished">Aktuelle Soundkarte testen</translation>
    </message>
    <message>
        <source>No sound cards/devices were found.</source>
        <translation type="vanished">Keine Soundkarte gefunden.</translation>
    </message>
    <message>
        <source>none</source>
        <translation type="vanished">keine</translation>
    </message>
    <message>
        <source>About MX Select Sound</source>
        <translation type="vanished">Über MX Soundkartenwahl</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Version:</translation>
    </message>
    <message>
        <source>Program for selecting the default sound card in MX Linux</source>
        <translation type="vanished">Programm zur Auswahl der voreingestellten (default) Soundkarte in MX Linux</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Lizenz</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Änderungsprotokoll</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Abbrechen</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Schließen</translation>
    </message>
    <message>
        <source>Could not play test sound.</source>
        <translation type="vanished">Der Testklang konnte nicht abgespielt werden.</translation>
    </message>
</context>
</TS>
